@@ -111,13 +111,13 @@ def run(request="request",
     # <editor-fold desc="Prepare general objects">
     context["objects"]["rules_list"] = rules_list
 
-    logging.info(msg="context:{}".format(str(context)))
+    logger.info(msg="context:{}".format(str(context)))
     data_input = {}
     testing = {}
     # </editor-fold>
     for rule in rules_list:
         if rule["active"] == 'True':
-            logging.info(msg="start processing rule config object:{}".format(str(rule)))
+            logger.info(msg="start processing rule config object:{}".format(str(rule)))
             # <editor-fold desc="Construct query based on rule and get data from source">
             data_input["query"] = construct_query(rule,monitoring_table=monitoring_table)
             data_input_table = context["clients"]["bigQuery"].query(data_input["query"])
@@ -158,17 +158,17 @@ def run(request="request",
             data_output["log"]["records"] = len(data_output["log"]["table"])
             data_output["notifications"]["records"] = len(data_output["notifications"]["table"])
 
-            logging.info(msg="entries to evaluate:{}".format(data_output["log"]["records"]))
+            logger.info(msg="entries to evaluate:{}".format(data_output["log"]["records"]))
 
             if data_output["log"]["records"] > 0:
                 monitoring_table.upload(data_output["log"]["table"].to_dict("records"),
                                         config_object={"schema": monitoring_table.schema},
                                         create_nonexisting_table=True)
 
-            logging.info(msg="entries went through notification:{}".format(data_output["notifications"]["records"]))
+            logger.info(msg="entries went through notification:{}".format(data_output["notifications"]["records"]))
             if data_output["notifications"]["records"] > 0:
                 if "slack" in rule["notifications"]:
-                    logging.info(msg="prepare sending slack message")
+                    logger.info(msg="prepare sending slack message")
                     data_output["notifications"]["slack_message"] = construct_notification_message(
                         message=rule["notifications"]["slack"]["message"],
                         table=data_output["notifications"]["table"]
